@@ -1040,11 +1040,7 @@ class ProbeTask(AbstractModel):
 
 
 class ProbeTaskBasicConfiguration(AbstractModel):
-    """type ProbeTaskBasicConfiguration struct {
-    	TaskID        TaskID `json:"TaskId" gorm:"column:task_id"`
-    	Name          string `json:"Name" binding:"required" gorm:"column:name"`
-    	TargetAddress string `json:"TargetAddress" binding:"required" gorm:"column:target_address"`
-    }
+    """拨测任务基础配置
 
     """
 
