@@ -56,8 +56,8 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateBatchCancelFlowUrl(self, request):
-        """指定需要批量撤回的签署流程Id，获取批量撤销链接
-        客户指定需要撤回的签署流程Id，最多100个，超过100不处理；接口调用成功返回批量撤回合同的链接，通过链接跳转到电子签小程序完成批量撤回
+        """指定需要批量撤销的签署流程Id，获取批量撤销链接
+        客户指定需要撤销的签署流程Id，最多100个，超过100不处理；接口调用成功返回批量撤销合同的链接，通过链接跳转到电子签小程序完成批量撤销
 
         :param request: Request instance for ChannelCreateBatchCancelFlowUrl.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateBatchCancelFlowUrlRequest`
