@@ -36,7 +36,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AssignProject", params)
+            headers = request.headers
+            body = self.call("AssignProject", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AssignProjectResponse()
@@ -64,7 +65,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateBackupDBInstance", params)
+            headers = request.headers
+            body = self.call("CreateBackupDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateBackupDBInstanceResponse()
@@ -92,7 +94,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateBackupDownloadTask", params)
+            headers = request.headers
+            body = self.call("CreateBackupDownloadTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateBackupDownloadTaskResponse()
@@ -120,7 +123,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDBInstance", params)
+            headers = request.headers
+            body = self.call("CreateDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDBInstanceResponse()
@@ -148,7 +152,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDBInstanceHour", params)
+            headers = request.headers
+            body = self.call("CreateDBInstanceHour", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDBInstanceHourResponse()
@@ -176,7 +181,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAsyncRequestInfo", params)
+            headers = request.headers
+            body = self.call("DescribeAsyncRequestInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAsyncRequestInfoResponse()
@@ -194,36 +200,6 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeBackupAccess(self, request):
-        """备份下载功能已调整，此接口即将下线
-
-        本接口（DescribeBackupAccess）用于获取备份文件的下载授权，具体的备份文件信息可通过查询实例备份列表（DescribeDBBackups）接口获取
-
-        :param request: Request instance for DescribeBackupAccess.
-        :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeBackupAccessRequest`
-        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DescribeBackupAccessResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeBackupAccess", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeBackupAccessResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeBackupDownloadTask(self, request):
         """查询备份下载任务信息
 
@@ -234,7 +210,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBackupDownloadTask", params)
+            headers = request.headers
+            body = self.call("DescribeBackupDownloadTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBackupDownloadTaskResponse()
@@ -262,7 +239,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClientConnections", params)
+            headers = request.headers
+            body = self.call("DescribeClientConnections", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClientConnectionsResponse()
@@ -290,7 +268,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCurrentOp", params)
+            headers = request.headers
+            body = self.call("DescribeCurrentOp", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCurrentOpResponse()
@@ -318,7 +297,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBBackups", params)
+            headers = request.headers
+            body = self.call("DescribeDBBackups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBBackupsResponse()
@@ -346,7 +326,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBInstanceDeal", params)
+            headers = request.headers
+            body = self.call("DescribeDBInstanceDeal", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBInstanceDealResponse()
@@ -374,7 +355,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBInstances", params)
+            headers = request.headers
+            body = self.call("DescribeDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBInstancesResponse()
@@ -402,7 +384,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstanceParams", params)
+            headers = request.headers
+            body = self.call("DescribeInstanceParams", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstanceParamsResponse()
@@ -430,7 +413,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSecurityGroup", params)
+            headers = request.headers
+            body = self.call("DescribeSecurityGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSecurityGroupResponse()
@@ -458,7 +442,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSlowLogPatterns", params)
+            headers = request.headers
+            body = self.call("DescribeSlowLogPatterns", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSlowLogPatternsResponse()
@@ -486,7 +471,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSlowLogs", params)
+            headers = request.headers
+            body = self.call("DescribeSlowLogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSlowLogsResponse()
@@ -514,7 +500,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSpecInfo", params)
+            headers = request.headers
+            body = self.call("DescribeSpecInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSpecInfoResponse()
@@ -542,7 +529,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("FlushInstanceRouterConfig", params)
+            headers = request.headers
+            body = self.call("FlushInstanceRouterConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.FlushInstanceRouterConfigResponse()
@@ -570,7 +558,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquirePriceCreateDBInstances", params)
+            headers = request.headers
+            body = self.call("InquirePriceCreateDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquirePriceCreateDBInstancesResponse()
@@ -598,7 +587,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquirePriceModifyDBInstanceSpec", params)
+            headers = request.headers
+            body = self.call("InquirePriceModifyDBInstanceSpec", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquirePriceModifyDBInstanceSpecResponse()
@@ -626,7 +616,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquirePriceRenewDBInstances", params)
+            headers = request.headers
+            body = self.call("InquirePriceRenewDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquirePriceRenewDBInstancesResponse()
@@ -654,7 +645,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("IsolateDBInstance", params)
+            headers = request.headers
+            body = self.call("IsolateDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.IsolateDBInstanceResponse()
@@ -682,7 +674,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("KillOps", params)
+            headers = request.headers
+            body = self.call("KillOps", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.KillOpsResponse()
@@ -710,7 +703,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceNetworkAddress", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceNetworkAddress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceNetworkAddressResponse()
@@ -738,7 +732,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceSecurityGroup", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceSecurityGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceSecurityGroupResponse()
@@ -766,7 +761,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceSpec", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceSpec", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceSpecResponse()
@@ -794,7 +790,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("OfflineIsolatedDBInstance", params)
+            headers = request.headers
+            body = self.call("OfflineIsolatedDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.OfflineIsolatedDBInstanceResponse()
@@ -822,7 +819,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RenameInstance", params)
+            headers = request.headers
+            body = self.call("RenameInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RenameInstanceResponse()
@@ -850,7 +848,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RenewDBInstances", params)
+            headers = request.headers
+            body = self.call("RenewDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RenewDBInstancesResponse()
@@ -878,7 +877,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ResetDBInstancePassword", params)
+            headers = request.headers
+            body = self.call("ResetDBInstancePassword", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ResetDBInstancePasswordResponse()
@@ -906,7 +906,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetAccountUserPrivilege", params)
+            headers = request.headers
+            body = self.call("SetAccountUserPrivilege", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetAccountUserPrivilegeResponse()
