@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,7 +27,9 @@ class TcexClient(AbstractClient):
 
 
     def DescribeInvocationResult(self, request):
-        """获取服务调用结果。和InvokeService接口配置合适，其InvokeId参数为InvokeService接口返回的RequestId。
+        """产品控制台已经下线
+
+        获取服务调用结果。和InvokeService接口配置合适，其InvokeId参数为InvokeService接口返回的RequestId。
 
         :param request: Request instance for DescribeInvocationResult.
         :type request: :class:`tencentcloud.tcex.v20200727.models.DescribeInvocationResultRequest`
@@ -36,7 +38,8 @@ class TcexClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInvocationResult", params)
+            headers = request.headers
+            body = self.call("DescribeInvocationResult", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInvocationResultResponse()
@@ -55,7 +58,9 @@ class TcexClient(AbstractClient):
 
 
     def InvokeService(self, request):
-        """通过传入文档url，测试服务算法。此接口需要和DescribeInvocationResult接口配置使用，该接口使用InvokeService返回的RequestId作为InvokeId参数，用于查询调用结果。
+        """产品控制台已经下线
+
+        通过传入文档url，测试服务算法。此接口需要和DescribeInvocationResult接口配置使用，该接口使用InvokeService返回的RequestId作为InvokeId参数，用于查询调用结果。
 
         :param request: Request instance for InvokeService.
         :type request: :class:`tencentcloud.tcex.v20200727.models.InvokeServiceRequest`
@@ -64,7 +69,8 @@ class TcexClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InvokeService", params)
+            headers = request.headers
+            body = self.call("InvokeService", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InvokeServiceResponse()
